Class: Aws::S3Vectors::Client

Inherits:
Seahorse::Client::Base
  • Object
show all
Includes:
ClientStubs
Defined in:
lib/aws-sdk-s3vectors/client.rb

Overview

An API client for S3Vectors. To construct a client, you need to configure a ‘:region` and `:credentials`.

client = Aws::S3Vectors::Client.new(
  region: region_name,
  credentials: credentials,
  # ...
)

For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).

See #initialize for a full list of supported configuration options.

Class Attribute Summary collapse

API Operations collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ Client

Returns a new instance of Client.

Parameters:

  • options (Hash)

Options Hash (options):

  • :plugins (Array<Seahorse::Client::Plugin>) — default: []]

    A list of plugins to apply to the client. Each plugin is either a class name or an instance of a plugin class.

  • :credentials (required, Aws::CredentialProvider)

    Your AWS credentials used for authentication. This can be any class that includes and implements ‘Aws::CredentialProvider`, or instance of any one of the following classes:

    • ‘Aws::Credentials` - Used for configuring static, non-refreshing credentials.

    • ‘Aws::SharedCredentials` - Used for loading static credentials from a shared file, such as `~/.aws/config`.

    • ‘Aws::AssumeRoleCredentials` - Used when you need to assume a role.

    • ‘Aws::AssumeRoleWebIdentityCredentials` - Used when you need to assume a role after providing credentials via the web.

    • ‘Aws::SSOCredentials` - Used for loading credentials from AWS SSO using an access token generated from `aws login`.

    • ‘Aws::ProcessCredentials` - Used for loading credentials from a process that outputs to stdout.

    • ‘Aws::InstanceProfileCredentials` - Used for loading credentials from an EC2 IMDS on an EC2 instance.

    • ‘Aws::ECSCredentials` - Used for loading credentials from instances running in ECS.

    • ‘Aws::CognitoIdentityCredentials` - Used for loading credentials from the Cognito Identity service.

    When ‘:credentials` are not configured directly, the following locations will be searched for credentials:

    • Aws.config`

    • The ‘:access_key_id`, `:secret_access_key`, `:session_token`, and `:account_id` options.

    • ENV`, `ENV`, `ENV`, and `ENV`.

    • ‘~/.aws/credentials`

    • ‘~/.aws/config`

    • EC2/ECS IMDS instance profile - When used by default, the timeouts are very aggressive. Construct and pass an instance of ‘Aws::InstanceProfileCredentials` or `Aws::ECSCredentials` to enable retries and extended timeouts. Instance profile credential fetching can be disabled by setting `ENV` to `true`.

  • :region (required, String)

    The AWS region to connect to. The configured ‘:region` is used to determine the service `:endpoint`. When not passed, a default `:region` is searched for in the following locations:

  • :access_key_id (String)
  • :account_id (String)
  • :active_endpoint_cache (Boolean) — default: false

    When set to ‘true`, a thread polling for endpoints will be running in the background every 60 secs (default). Defaults to `false`.

  • :adaptive_retry_wait_to_fill (Boolean) — default: true

    Used only in ‘adaptive` retry mode. When true, the request will sleep until there is sufficent client side capacity to retry the request. When false, the request will raise a `RetryCapacityNotAvailableError` and will not retry instead of sleeping.

  • :auth_scheme_preference (Array<String>)

    A list of preferred authentication schemes to use when making a request. Supported values are: ‘sigv4`, `sigv4a`, `httpBearerAuth`, and `noAuth`. When set using `ENV` or in shared config as `auth_scheme_preference`, the value should be a comma-separated list.

  • :client_side_monitoring (Boolean) — default: false

    When ‘true`, client-side metrics will be collected for all API requests from this client.

  • :client_side_monitoring_client_id (String) — default: ""

    Allows you to provide an identifier for this client which will be attached to all generated client side metrics. Defaults to an empty string.

  • :client_side_monitoring_host (String) — default: "127.0.0.1"

    Allows you to specify the DNS hostname or IPv4 or IPv6 address that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_port (Integer) — default: 31000

    Required for publishing client metrics. The port that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_publisher (Aws::ClientSideMonitoring::Publisher) — default: Aws::ClientSideMonitoring::Publisher

    Allows you to provide a custom client-side monitoring publisher class. By default, will use the Client Side Monitoring Agent Publisher.

  • :convert_params (Boolean) — default: true

    When ‘true`, an attempt is made to coerce request parameters into the required types.

  • :correct_clock_skew (Boolean) — default: true

    Used only in ‘standard` and `adaptive` retry modes. Specifies whether to apply a clock skew correction and retry requests with skewed client clocks.

  • :defaults_mode (String) — default: "legacy"

    See DefaultsModeConfiguration for a list of the accepted modes and the configuration defaults that are included.

  • :disable_host_prefix_injection (Boolean) — default: false

    When ‘true`, the SDK will not prepend the modeled host prefix to the endpoint.

  • :disable_request_compression (Boolean) — default: false

    When set to ‘true’ the request body will not be compressed for supported operations.

  • :endpoint (String, URI::HTTPS, URI::HTTP)

    Normally you should not configure the ‘:endpoint` option directly. This is normally constructed from the `:region` option. Configuring `:endpoint` is normally reserved for connecting to test or custom endpoints. The endpoint should be a URI formatted like:

    'http://example.com'
    'https://example.com'
    'http://example.com:123'
    
  • :endpoint_cache_max_entries (Integer) — default: 1000

    Used for the maximum size limit of the LRU cache storing endpoints data for endpoint discovery enabled operations. Defaults to 1000.

  • :endpoint_cache_max_threads (Integer) — default: 10

    Used for the maximum threads in use for polling endpoints to be cached, defaults to 10.

  • :endpoint_cache_poll_interval (Integer) — default: 60

    When :endpoint_discovery and :active_endpoint_cache is enabled, Use this option to config the time interval in seconds for making requests fetching endpoints information. Defaults to 60 sec.

  • :endpoint_discovery (Boolean) — default: false

    When set to ‘true`, endpoint discovery will be enabled for operations when available.

  • :ignore_configured_endpoint_urls (Boolean)

    Setting to true disables use of endpoint URLs provided via environment variables and the shared configuration file.

  • :log_formatter (Aws::Log::Formatter) — default: Aws::Log::Formatter.default

    The log formatter.

  • :log_level (Symbol) — default: :info

    The log level to send messages to the ‘:logger` at.

  • :logger (Logger)

    The Logger instance to send log messages to. If this option is not set, logging will be disabled.

  • :max_attempts (Integer) — default: 3

    An integer representing the maximum number attempts that will be made for a single request, including the initial attempt. For example, setting this value to 5 will result in a request being retried up to 4 times. Used in ‘standard` and `adaptive` retry modes.

  • :profile (String) — default: "default"

    Used when loading credentials from the shared credentials file at ‘HOME/.aws/credentials`. When not specified, ’default’ is used.

  • :request_checksum_calculation (String) — default: "when_supported"

    Determines when a checksum will be calculated for request payloads. Values are:

    • ‘when_supported` - (default) When set, a checksum will be calculated for all request payloads of operations modeled with the `httpChecksum` trait where `requestChecksumRequired` is `true` and/or a `requestAlgorithmMember` is modeled.

    • ‘when_required` - When set, a checksum will only be calculated for request payloads of operations modeled with the `httpChecksum` trait where `requestChecksumRequired` is `true` or where a `requestAlgorithmMember` is modeled and supplied.

  • :request_min_compression_size_bytes (Integer) — default: 10240

    The minimum size in bytes that triggers compression for request bodies. The value must be non-negative integer value between 0 and 10485780 bytes inclusive.

  • :response_checksum_validation (String) — default: "when_supported"

    Determines when checksum validation will be performed on response payloads. Values are:

    • ‘when_supported` - (default) When set, checksum validation is performed on all response payloads of operations modeled with the `httpChecksum` trait where `responseAlgorithms` is modeled, except when no modeled checksum algorithms are supported.

    • ‘when_required` - When set, checksum validation is not performed on response payloads of operations unless the checksum algorithm is supported and the `requestValidationModeMember` member is set to `ENABLED`.

  • :retry_backoff (Proc)

    A proc or lambda used for backoff. Defaults to 2**retries * retry_base_delay. This option is only used in the ‘legacy` retry mode.

  • :retry_base_delay (Float) — default: 0.3

    The base delay in seconds used by the default backoff function. This option is only used in the ‘legacy` retry mode.

  • :retry_jitter (Symbol) — default: :none

    A delay randomiser function used by the default backoff function. Some predefined functions can be referenced by name - :none, :equal, :full, otherwise a Proc that takes and returns a number. This option is only used in the ‘legacy` retry mode.

    @see www.awsarchitectureblog.com/2015/03/backoff.html

  • :retry_limit (Integer) — default: 3

    The maximum number of times to retry failed requests. Only ~ 500 level server errors and certain ~ 400 level client errors are retried. Generally, these are throttling errors, data checksum errors, networking errors, timeout errors, auth errors, endpoint discovery, and errors from expired credentials. This option is only used in the ‘legacy` retry mode.

  • :retry_max_delay (Integer) — default: 0

    The maximum number of seconds to delay between retries (0 for no limit) used by the default backoff function. This option is only used in the ‘legacy` retry mode.

  • :retry_mode (String) — default: "legacy"

    Specifies which retry algorithm to use. Values are:

    • ‘legacy` - The pre-existing retry behavior. This is the default value if no retry mode is provided.

    • ‘standard` - A standardized set of retry rules across the AWS SDKs. This includes support for retry quotas, which limit the number of unsuccessful retries a client can make.

    • ‘adaptive` - A retry mode that includes all the functionality of `standard` mode along with automatic client side throttling.

  • :sdk_ua_app_id (String)

    A unique and opaque application ID that is appended to the User-Agent header as app/sdk_ua_app_id. It should have a maximum length of 50. This variable is sourced from environment variable AWS_SDK_UA_APP_ID or the shared config profile attribute sdk_ua_app_id.

  • :secret_access_key (String)
  • :session_token (String)
  • :sigv4a_signing_region_set (Array)

    A list of regions that should be signed with SigV4a signing. When not passed, a default ‘:sigv4a_signing_region_set` is searched for in the following locations:

  • :stub_responses (Boolean) — default: false

    Causes the client to return stubbed responses. By default fake responses are generated and returned. You can specify the response data to return or errors to raise by calling ClientStubs#stub_responses. See ClientStubs for more information.

    ** Please note ** When response stubbing is enabled, no HTTP requests are made, and retries are disabled.

  • :telemetry_provider (Aws::Telemetry::TelemetryProviderBase) — default: Aws::Telemetry::NoOpTelemetryProvider

    Allows you to provide a telemetry provider, which is used to emit telemetry data. By default, uses ‘NoOpTelemetryProvider` which will not record or emit any telemetry data. The SDK supports the following telemetry providers:

    • OpenTelemetry (OTel) - To use the OTel provider, install and require the

    ‘opentelemetry-sdk` gem and then, pass in an instance of a `Aws::Telemetry::OTelProvider` for telemetry provider.

  • :token_provider (Aws::TokenProvider)

    Your Bearer token used for authentication. This can be any class that includes and implements ‘Aws::TokenProvider`, or instance of any one of the following classes:

    • ‘Aws::StaticTokenProvider` - Used for configuring static, non-refreshing tokens.

    • ‘Aws::SSOTokenProvider` - Used for loading tokens from AWS SSO using an access token generated from `aws login`.

    When ‘:token_provider` is not configured directly, the `Aws::TokenProviderChain` will be used to search for tokens configured for your profile in shared configuration files.

  • :use_dualstack_endpoint (Boolean)

    When set to ‘true`, dualstack enabled endpoints (with `.aws` TLD) will be used if available.

  • :use_fips_endpoint (Boolean)

    When set to ‘true`, fips compatible endpoints will be used if available. When a `fips` region is used, the region is normalized and this config is set to `true`.

  • :validate_params (Boolean) — default: true

    When ‘true`, request parameters are validated before sending the request.

  • :endpoint_provider (Aws::S3Vectors::EndpointProvider)

    The endpoint provider used to resolve endpoints. Any object that responds to ‘#resolve_endpoint(parameters)` where `parameters` is a Struct similar to `Aws::S3Vectors::EndpointParameters`.

  • :http_continue_timeout (Float) — default: 1

    The number of seconds to wait for a 100-continue response before sending the request body. This option has no effect unless the request has “Expect” header set to “100-continue”. Defaults to ‘nil` which disables this behaviour. This value can safely be set per request on the session.

  • :http_idle_timeout (Float) — default: 5

    The number of seconds a connection is allowed to sit idle before it is considered stale. Stale connections are closed and removed from the pool before making a request.

  • :http_open_timeout (Float) — default: 15

    The default number of seconds to wait for response data. This value can safely be set per-request on the session.

  • :http_proxy (URI::HTTP, String)

    A proxy to send requests through. Formatted like ‘proxy.com:123’.

  • :http_read_timeout (Float) — default: 60

    The default number of seconds to wait for response data. This value can safely be set per-request on the session.

  • :http_wire_trace (Boolean) — default: false

    When ‘true`, HTTP debug output will be sent to the `:logger`.

  • :on_chunk_received (Proc)

    When a Proc object is provided, it will be used as callback when each chunk of the response body is received. It provides three arguments: the chunk, the number of bytes received, and the total number of bytes in the response (or nil if the server did not send a ‘content-length`).

  • :on_chunk_sent (Proc)

    When a Proc object is provided, it will be used as callback when each chunk of the request body is sent. It provides three arguments: the chunk, the number of bytes read from the body, and the total number of bytes in the body.

  • :raise_response_errors (Boolean) — default: true

    When ‘true`, response errors are raised.

  • :ssl_ca_bundle (String)

    Full path to the SSL certificate authority bundle file that should be used when verifying peer certificates. If you do not pass ‘:ssl_ca_bundle` or `:ssl_ca_directory` the the system default will be used if available.

  • :ssl_ca_directory (String)

    Full path of the directory that contains the unbundled SSL certificate authority files for verifying peer certificates. If you do not pass ‘:ssl_ca_bundle` or `:ssl_ca_directory` the the system default will be used if available.

  • :ssl_ca_store (String)

    Sets the X509::Store to verify peer certificate.

  • :ssl_cert (OpenSSL::X509::Certificate)

    Sets a client certificate when creating http connections.

  • :ssl_key (OpenSSL::PKey)

    Sets a client key when creating http connections.

  • :ssl_timeout (Float)

    Sets the SSL timeout in seconds

  • :ssl_verify_peer (Boolean) — default: true

    When ‘true`, SSL peer certificates are verified when establishing a connection.



471
472
473
# File 'lib/aws-sdk-s3vectors/client.rb', line 471

def initialize(*args)
  super
end

Class Attribute Details

.identifierObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1617
1618
1619
# File 'lib/aws-sdk-s3vectors/client.rb', line 1617

def identifier
  @identifier
end

Class Method Details

.errors_moduleObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1620
1621
1622
# File 'lib/aws-sdk-s3vectors/client.rb', line 1620

def errors_module
  Errors
end

Instance Method Details

#build_request(operation_name, params = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • params ({}) (defaults to: {})


1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
# File 'lib/aws-sdk-s3vectors/client.rb', line 1590

def build_request(operation_name, params = {})
  handlers = @handlers.for(operation_name)
  tracer = config.telemetry_provider.tracer_provider.tracer(
    Aws::Telemetry.module_to_tracer_name('Aws::S3Vectors')
  )
  context = Seahorse::Client::RequestContext.new(
    operation_name: operation_name,
    operation: config.api.operation(operation_name),
    client: self,
    params: params,
    config: config,
    tracer: tracer
  )
  context[:gem_name] = 'aws-sdk-s3vectors'
  context[:gem_version] = '1.17.0'
  Seahorse::Client::Request.new(handlers, context)
end

#create_index(params = {}) ⇒ Types::CreateIndexOutput

Creates a vector index within a vector bucket. To specify the vector bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).

Permissions

: You must have the ‘s3vectors:CreateIndex` permission to use this

operation.

You must have the `s3vectors:TagResource` permission in addition to
`s3vectors:CreateIndex` permission to create a vector index with
tags.

Examples:

Request syntax with placeholder values


resp = client.create_index({
  vector_bucket_name: "VectorBucketName",
  vector_bucket_arn: "VectorBucketArn",
  index_name: "IndexName", # required
  data_type: "float32", # required, accepts float32
  dimension: 1, # required
  distance_metric: "euclidean", # required, accepts euclidean, cosine
  metadata_configuration: {
    non_filterable_metadata_keys: ["MetadataKey"], # required
  },
  encryption_configuration: {
    sse_type: "AES256", # accepts AES256, aws:kms
    kms_key_arn: "KmsKeyArn",
  },
  tags: {
    "TagKey" => "TagValue",
  },
})

Response structure


resp.index_arn #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :vector_bucket_name (String)

    The name of the vector bucket to create the vector index in.

  • :vector_bucket_arn (String)

    The Amazon Resource Name (ARN) of the vector bucket to create the vector index in.

  • :index_name (required, String)

    The name of the vector index to create.

  • :data_type (required, String)

    The data type of the vectors to be inserted into the vector index.

  • :dimension (required, Integer)

    The dimensions of the vectors to be inserted into the vector index.

  • :distance_metric (required, String)

    The distance metric to be used for similarity search.

  • :metadata_configuration (Types::MetadataConfiguration)

    The metadata configuration for the vector index.

  • :encryption_configuration (Types::EncryptionConfiguration)

    The encryption configuration for a vector index. By default, if you don’t specify, all new vectors in the vector index will use the encryption configuration of the vector bucket.

  • :tags (Hash<String,String>)

    An array of user-defined tags that you would like to apply to the vector index that you are creating. A tag is a key-value pair that you apply to your resources. Tags can help you organize, track costs, and control access to resources. For more information, see [Tagging for cost allocation or attribute-based access control (ABAC)].

    <note markdown=“1”> You must have the ‘s3vectors:TagResource` permission in addition to `s3vectors:CreateIndex` permission to create a vector index with tags.

    </note>
    

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/tagging.html

Returns:

See Also:



566
567
568
569
# File 'lib/aws-sdk-s3vectors/client.rb', line 566

def create_index(params = {}, options = {})
  req = build_request(:create_index, params)
  req.send_request(options)
end

#create_vector_bucket(params = {}) ⇒ Types::CreateVectorBucketOutput

Creates a vector bucket in the Amazon Web Services Region that you want your bucket to be in.

Permissions

: You must have the ‘s3vectors:CreateVectorBucket` permission to use

this operation.

You must have the `s3vectors:TagResource` permission in addition to
`s3vectors:CreateVectorBucket` permission to create a vector bucket
with tags.

Examples:

Request syntax with placeholder values


resp = client.create_vector_bucket({
  vector_bucket_name: "VectorBucketName", # required
  encryption_configuration: {
    sse_type: "AES256", # accepts AES256, aws:kms
    kms_key_arn: "KmsKeyArn",
  },
  tags: {
    "TagKey" => "TagValue",
  },
})

Response structure


resp.vector_bucket_arn #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :vector_bucket_name (required, String)

    The name of the vector bucket to create.

  • :encryption_configuration (Types::EncryptionConfiguration)

    The encryption configuration for the vector bucket. By default, if you don’t specify, all new vectors in Amazon S3 vector buckets use server-side encryption with Amazon S3 managed keys (SSE-S3), specifically ‘AES256`.

  • :tags (Hash<String,String>)

    An array of user-defined tags that you would like to apply to the vector bucket that you are creating. A tag is a key-value pair that you apply to your resources. Tags can help you organize and control access to resources. For more information, see [Tagging for cost allocation or attribute-based access control (ABAC)].

    <note markdown=“1”> You must have the ‘s3vectors:TagResource` permission in addition to `s3vectors:CreateVectorBucket` permission to create a vector bucket with tags.

    </note>
    

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/tagging.html

Returns:

See Also:



634
635
636
637
# File 'lib/aws-sdk-s3vectors/client.rb', line 634

def create_vector_bucket(params = {}, options = {})
  req = build_request(:create_vector_bucket, params)
  req.send_request(options)
end

#delete_index(params = {}) ⇒ Struct

Deletes a vector index. To specify the vector index, you can either use both the vector bucket name and vector index name, or use the vector index Amazon Resource Name (ARN).

Permissions

: You must have the ‘s3vectors:DeleteIndex` permission to use this

operation.

Examples:

Request syntax with placeholder values


resp = client.delete_index({
  vector_bucket_name: "VectorBucketName",
  index_name: "IndexName",
  index_arn: "IndexArn",
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :vector_bucket_name (String)

    The name of the vector bucket that contains the vector index.

  • :index_name (String)

    The name of the vector index to delete.

  • :index_arn (String)

    The ARN of the vector index to delete.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



671
672
673
674
# File 'lib/aws-sdk-s3vectors/client.rb', line 671

def delete_index(params = {}, options = {})
  req = build_request(:delete_index, params)
  req.send_request(options)
end

#delete_vector_bucket(params = {}) ⇒ Struct

Deletes a vector bucket. All vector indexes in the vector bucket must be deleted before the vector bucket can be deleted. To perform this operation, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).

Permissions

: You must have the ‘s3vectors:DeleteVectorBucket` permission to use

this operation.

Examples:

Request syntax with placeholder values


resp = client.delete_vector_bucket({
  vector_bucket_name: "VectorBucketName",
  vector_bucket_arn: "VectorBucketArn",
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :vector_bucket_name (String)

    The name of the vector bucket to delete.

  • :vector_bucket_arn (String)

    The ARN of the vector bucket to delete.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



705
706
707
708
# File 'lib/aws-sdk-s3vectors/client.rb', line 705

def delete_vector_bucket(params = {}, options = {})
  req = build_request(:delete_vector_bucket, params)
  req.send_request(options)
end

#delete_vector_bucket_policy(params = {}) ⇒ Struct

Deletes a vector bucket policy. To specify the bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).

Permissions

: You must have the ‘s3vectors:DeleteVectorBucketPolicy` permission to

use this operation.

Examples:

Request syntax with placeholder values


resp = client.delete_vector_bucket_policy({
  vector_bucket_name: "VectorBucketName",
  vector_bucket_arn: "VectorBucketArn",
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :vector_bucket_name (String)

    The name of the vector bucket to delete the policy from.

  • :vector_bucket_arn (String)

    The ARN of the vector bucket to delete the policy from.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



738
739
740
741
# File 'lib/aws-sdk-s3vectors/client.rb', line 738

def delete_vector_bucket_policy(params = {}, options = {})
  req = build_request(:delete_vector_bucket_policy, params)
  req.send_request(options)
end

#delete_vectors(params = {}) ⇒ Struct

Deletes one or more vectors in a vector index. To specify the vector index, you can either use both the vector bucket name and vector index name, or use the vector index Amazon Resource Name (ARN).

Permissions

: You must have the ‘s3vectors:DeleteVectors` permission to use this

operation.

Examples:

Request syntax with placeholder values


resp = client.delete_vectors({
  vector_bucket_name: "VectorBucketName",
  index_name: "IndexName",
  index_arn: "IndexArn",
  keys: ["VectorKey"], # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :vector_bucket_name (String)

    The name of the vector bucket that contains the vector index.

  • :index_name (String)

    The name of the vector index that contains a vector you want to delete.

  • :index_arn (String)

    The ARN of the vector index that contains a vector you want to delete.

  • :keys (required, Array<String>)

    The keys of the vectors to delete.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



780
781
782
783
# File 'lib/aws-sdk-s3vectors/client.rb', line 780

def delete_vectors(params = {}, options = {})
  req = build_request(:delete_vectors, params)
  req.send_request(options)
end

#get_index(params = {}) ⇒ Types::GetIndexOutput

Returns vector index attributes. To specify the vector index, you can either use both the vector bucket name and the vector index name, or use the vector index Amazon Resource Name (ARN).

Permissions

: You must have the ‘s3vectors:GetIndex` permission to use this

operation.

Examples:

Request syntax with placeholder values


resp = client.get_index({
  vector_bucket_name: "VectorBucketName",
  index_name: "IndexName",
  index_arn: "IndexArn",
})

Response structure


resp.index.vector_bucket_name #=> String
resp.index.index_name #=> String
resp.index.index_arn #=> String
resp.index.creation_time #=> Time
resp.index.data_type #=> String, one of "float32"
resp.index.dimension #=> Integer
resp.index.distance_metric #=> String, one of "euclidean", "cosine"
resp.index.. #=> Array
resp.index..[0] #=> String
resp.index.encryption_configuration.sse_type #=> String, one of "AES256", "aws:kms"
resp.index.encryption_configuration.kms_key_arn #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :vector_bucket_name (String)

    The name of the vector bucket that contains the vector index.

  • :index_name (String)

    The name of the vector index.

  • :index_arn (String)

    The ARN of the vector index.

Returns:

See Also:



833
834
835
836
# File 'lib/aws-sdk-s3vectors/client.rb', line 833

def get_index(params = {}, options = {})
  req = build_request(:get_index, params)
  req.send_request(options)
end

#get_vector_bucket(params = {}) ⇒ Types::GetVectorBucketOutput

Returns vector bucket attributes. To specify the bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).

Permissions

: You must have the ‘s3vectors:GetVectorBucket` permission to use this

operation.

Examples:

Request syntax with placeholder values


resp = client.get_vector_bucket({
  vector_bucket_name: "VectorBucketName",
  vector_bucket_arn: "VectorBucketArn",
})

Response structure


resp.vector_bucket.vector_bucket_name #=> String
resp.vector_bucket.vector_bucket_arn #=> String
resp.vector_bucket.creation_time #=> Time
resp.vector_bucket.encryption_configuration.sse_type #=> String, one of "AES256", "aws:kms"
resp.vector_bucket.encryption_configuration.kms_key_arn #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :vector_bucket_name (String)

    The name of the vector bucket to retrieve information about.

  • :vector_bucket_arn (String)

    The ARN of the vector bucket to retrieve information about.

Returns:

See Also:



876
877
878
879
# File 'lib/aws-sdk-s3vectors/client.rb', line 876

def get_vector_bucket(params = {}, options = {})
  req = build_request(:get_vector_bucket, params)
  req.send_request(options)
end

#get_vector_bucket_policy(params = {}) ⇒ Types::GetVectorBucketPolicyOutput

Gets details about a vector bucket policy. To specify the bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).

Permissions

: You must have the ‘s3vectors:GetVectorBucketPolicy` permission to

use this operation.

Examples:

Request syntax with placeholder values


resp = client.get_vector_bucket_policy({
  vector_bucket_name: "VectorBucketName",
  vector_bucket_arn: "VectorBucketArn",
})

Response structure


resp.policy #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :vector_bucket_name (String)

    The name of the vector bucket.

  • :vector_bucket_arn (String)

    The ARN of the vector bucket.

Returns:

See Also:



915
916
917
918
# File 'lib/aws-sdk-s3vectors/client.rb', line 915

def get_vector_bucket_policy(params = {}, options = {})
  req = build_request(:get_vector_bucket_policy, params)
  req.send_request(options)
end

#get_vectors(params = {}) ⇒ Types::GetVectorsOutput

Returns vector attributes. To specify the vector index, you can either use both the vector bucket name and the vector index name, or use the vector index Amazon Resource Name (ARN).

Permissions

: You must have the ‘s3vectors:GetVectors` permission to use this

operation.

Examples:

Request syntax with placeholder values


resp = client.get_vectors({
  vector_bucket_name: "VectorBucketName",
  index_name: "IndexName",
  index_arn: "IndexArn",
  keys: ["VectorKey"], # required
  return_data: false,
  return_metadata: false,
})

Response structure


resp.vectors #=> Array
resp.vectors[0].key #=> String
resp.vectors[0].data.float32 #=> Array
resp.vectors[0].data.float32[0] #=> Float

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :vector_bucket_name (String)

    The name of the vector bucket that contains the vector index.

  • :index_name (String)

    The name of the vector index.

  • :index_arn (String)

    The ARN of the vector index.

  • :keys (required, Array<String>)

    The names of the vectors you want to return attributes for.

  • :return_data (Boolean)

    Indicates whether to include the vector data in the response. The default value is ‘false`.

  • :return_metadata (Boolean)

    Indicates whether to include metadata in the response. The default value is ‘false`.

Returns:

See Also:



975
976
977
978
# File 'lib/aws-sdk-s3vectors/client.rb', line 975

def get_vectors(params = {}, options = {})
  req = build_request(:get_vectors, params)
  req.send_request(options)
end

#list_indexes(params = {}) ⇒ Types::ListIndexesOutput

Returns a list of all the vector indexes within the specified vector bucket. To specify the bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).

Permissions

: You must have the ‘s3vectors:ListIndexes` permission to use this

operation.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_indexes({
  vector_bucket_name: "VectorBucketName",
  vector_bucket_arn: "VectorBucketArn",
  max_results: 1,
  next_token: "ListIndexesNextToken",
  prefix: "ListIndexesPrefix",
})

Response structure


resp.next_token #=> String
resp.indexes #=> Array
resp.indexes[0].vector_bucket_name #=> String
resp.indexes[0].index_name #=> String
resp.indexes[0].index_arn #=> String
resp.indexes[0].creation_time #=> Time

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :vector_bucket_name (String)

    The name of the vector bucket that contains the vector indexes.

  • :vector_bucket_arn (String)

    The ARN of the vector bucket that contains the vector indexes.

  • :max_results (Integer)

    The maximum number of items to be returned in the response.

  • :next_token (String)

    The previous pagination token.

  • :prefix (String)

    Limits the response to vector indexes that begin with the specified prefix.

Returns:

See Also:



1035
1036
1037
1038
# File 'lib/aws-sdk-s3vectors/client.rb', line 1035

def list_indexes(params = {}, options = {})
  req = build_request(:list_indexes, params)
  req.send_request(options)
end

#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput

Lists all of the tags applied to a specified Amazon S3 Vectors resource. Each tag is a label consisting of a key and value pair. Tags can help you organize, track costs for, and control access to resources.

<note markdown=“1”> For a list of S3 resources that support tagging, see [Managing tags for Amazon S3 resources].

</note>

Permissions

: For vector buckets and vector indexes, you must have the

`s3vectors:ListTagsForResource` permission to use this operation.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/tagging.html#manage-tags

Examples:

Request syntax with placeholder values


resp = client.list_tags_for_resource({
  resource_arn: "ResourceARN", # required
})

Response structure


resp.tags #=> Hash
resp.tags["TagKey"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    The Amazon Resource Name (ARN) of the Amazon S3 Vectors resource that you want to list tags for. The tagged resource can be a vector bucket or a vector index.

Returns:

See Also:



1083
1084
1085
1086
# File 'lib/aws-sdk-s3vectors/client.rb', line 1083

def list_tags_for_resource(params = {}, options = {})
  req = build_request(:list_tags_for_resource, params)
  req.send_request(options)
end

#list_vector_buckets(params = {}) ⇒ Types::ListVectorBucketsOutput

Returns a list of all the vector buckets that are owned by the authenticated sender of the request.

Permissions

: You must have the ‘s3vectors:ListVectorBuckets` permission to use

this operation.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_vector_buckets({
  max_results: 1,
  next_token: "ListVectorBucketsNextToken",
  prefix: "ListVectorBucketsPrefix",
})

Response structure


resp.next_token #=> String
resp.vector_buckets #=> Array
resp.vector_buckets[0].vector_bucket_name #=> String
resp.vector_buckets[0].vector_bucket_arn #=> String
resp.vector_buckets[0].creation_time #=> Time

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :max_results (Integer)

    The maximum number of vector buckets to be returned in the response.

  • :next_token (String)

    The previous pagination token.

  • :prefix (String)

    Limits the response to vector buckets that begin with the specified prefix.

Returns:

See Also:



1133
1134
1135
1136
# File 'lib/aws-sdk-s3vectors/client.rb', line 1133

def list_vector_buckets(params = {}, options = {})
  req = build_request(:list_vector_buckets, params)
  req.send_request(options)
end

#list_vectors(params = {}) ⇒ Types::ListVectorsOutput

List vectors in the specified vector index. To specify the vector index, you can either use both the vector bucket name and the vector index name, or use the vector index Amazon Resource Name (ARN).

‘ListVectors` operations proceed sequentially; however, for faster performance on a large number of vectors in a vector index, applications can request a parallel `ListVectors` operation by providing the `segmentCount` and `segmentIndex` parameters.

Permissions

: You must have the ‘s3vectors:ListVectors` permission to use this

operation. Additional permissions are required based on the request
parameters you specify:

* With only `s3vectors:ListVectors` permission, you can list vector
  keys when `returnData` and `returnMetadata` are both set to false
  or not specified..

* If you set `returnData` or `returnMetadata` to true, you must have
  both `s3vectors:ListVectors` and `s3vectors:GetVectors`
  permissions. The request fails with a `403 Forbidden` error if you
  request vector data or metadata without the `s3vectors:GetVectors`
  permission.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_vectors({
  vector_bucket_name: "VectorBucketName",
  index_name: "IndexName",
  index_arn: "IndexArn",
  max_results: 1,
  next_token: "ListVectorsNextToken",
  segment_count: 1,
  segment_index: 1,
  return_data: false,
  return_metadata: false,
})

Response structure


resp.next_token #=> String
resp.vectors #=> Array
resp.vectors[0].key #=> String
resp.vectors[0].data.float32 #=> Array
resp.vectors[0].data.float32[0] #=> Float

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :vector_bucket_name (String)

    The name of the vector bucket.

  • :index_name (String)

    The name of the vector index.

  • :index_arn (String)

    The Amazon resource Name (ARN) of the vector index.

  • :max_results (Integer)

    The maximum number of vectors to return on a page.

    If you don’t specify ‘maxResults`, the `ListVectors` operation uses a default value of 500.

    If the processed dataset size exceeds 1 MB before reaching the ‘maxResults` value, the operation stops and returns the vectors that are retrieved up to that point, along with a `nextToken` that you can use in a subsequent request to retrieve the next set of results.

  • :next_token (String)

    Pagination token from a previous request. The value of this field is empty for an initial request.

  • :segment_count (Integer)

    For a parallel ‘ListVectors` request, `segmentCount` represents the total number of vector segments into which the `ListVectors` operation will be divided. The value of `segmentCount` corresponds to the number of application workers that will perform the parallel `ListVectors` operation. For example, if you want to use four application threads to list vectors in a vector index, specify a `segmentCount` value of 4.

    If you specify a ‘segmentCount` value of 1, the `ListVectors` operation will be sequential rather than parallel.

    If you specify ‘segmentCount`, you must also specify `segmentIndex`.

  • :segment_index (Integer)

    For a parallel ‘ListVectors` request, `segmentIndex` is the index of the segment from which to list vectors in the current request. It identifies an individual segment to be listed by an application worker.

    Segment IDs are zero-based, so the first segment is always 0. For example, if you want to use four application threads to list vectors in a vector index, then the first thread specifies a ‘segmentIndex` value of 0, the second thread specifies 1, and so on.

    The value of ‘segmentIndex` must be less than the value provided for `segmentCount`.

    If you provide ‘segmentIndex`, you must also provide `segmentCount`.

  • :return_data (Boolean)

    If true, the vector data of each vector will be included in the response. The default value is ‘false`.

  • :return_metadata (Boolean)

    If true, the metadata associated with each vector will be included in the response. The default value is ‘false`.

Returns:

See Also:



1257
1258
1259
1260
# File 'lib/aws-sdk-s3vectors/client.rb', line 1257

def list_vectors(params = {}, options = {})
  req = build_request(:list_vectors, params)
  req.send_request(options)
end

#put_vector_bucket_policy(params = {}) ⇒ Struct

Creates a bucket policy for a vector bucket. To specify the bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).

Permissions

: You must have the ‘s3vectors:PutVectorBucketPolicy` permission to

use this operation.

Examples:

Request syntax with placeholder values


resp = client.put_vector_bucket_policy({
  vector_bucket_name: "VectorBucketName",
  vector_bucket_arn: "VectorBucketArn",
  policy: "VectorBucketPolicy", # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :vector_bucket_name (String)

    The name of the vector bucket.

  • :vector_bucket_arn (String)

    The Amazon Resource Name (ARN) of the vector bucket.

  • :policy (required, String)

    The ‘JSON` that defines the policy. For more information about bucket policies for S3 Vectors, see [Managing vector bucket policies] in the *Amazon S3 User Guide*.

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-vectors-bucket-policy.html

Returns:

  • (Struct)

    Returns an empty response.

See Also:



1300
1301
1302
1303
# File 'lib/aws-sdk-s3vectors/client.rb', line 1300

def put_vector_bucket_policy(params = {}, options = {})
  req = build_request(:put_vector_bucket_policy, params)
  req.send_request(options)
end

#put_vectors(params = {}) ⇒ Struct

Adds one or more vectors to a vector index. To specify the vector index, you can either use both the vector bucket name and the vector index name, or use the vector index Amazon Resource Name (ARN).

For more information about limits, see [Limitations and restrictions] in the *Amazon S3 User Guide*.

<note markdown=“1”> When inserting vector data into your vector index, you must provide the vector data as ‘float32` (32-bit floating point) values. If you pass higher-precision values to an Amazon Web Services SDK, S3 Vectors converts the values to 32-bit floating point before storing them, and `GetVectors`, `ListVectors`, and `QueryVectors` operations return the float32 values. Different Amazon Web Services SDKs may have different default numeric types, so ensure your vectors are properly formatted as `float32` values regardless of which SDK you’re using. For example, in Python, use ‘numpy.float32` or explicitly cast your values.

</note>

Permissions

: You must have the ‘s3vectors:PutVectors` permission to use this

operation.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-vectors-limitations.html

Examples:

Request syntax with placeholder values


resp = client.put_vectors({
  vector_bucket_name: "VectorBucketName",
  index_name: "IndexName",
  index_arn: "IndexArn",
  vectors: [ # required
    {
      key: "VectorKey", # required
      data: { # required
        float32: [1.0],
      },
      metadata: {
      },
    },
  ],
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :vector_bucket_name (String)

    The name of the vector bucket that contains the vector index.

  • :index_name (String)

    The name of the vector index where you want to write vectors.

  • :index_arn (String)

    The ARN of the vector index where you want to write vectors.

  • :vectors (required, Array<Types::PutInputVector>)

    The vectors to add to a vector index. The number of vectors in a single request must not exceed the resource capacity, otherwise the request will be rejected with the error ‘ServiceUnavailableException` with the error message “Currently unable to handle the request”.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



1373
1374
1375
1376
# File 'lib/aws-sdk-s3vectors/client.rb', line 1373

def put_vectors(params = {}, options = {})
  req = build_request(:put_vectors, params)
  req.send_request(options)
end

#query_vectors(params = {}) ⇒ Types::QueryVectorsOutput

Performs an approximate nearest neighbor search query in a vector index using a query vector. By default, it returns the keys of approximate nearest neighbors. You can optionally include the computed distance (between the query vector and each vector in the response), the vector data, and metadata of each vector in the response.

To specify the vector index, you can either use both the vector bucket name and the vector index name, or use the vector index Amazon Resource Name (ARN).

Permissions

: You must have the ‘s3vectors:QueryVectors` permission to use this

operation. Additional permissions are required based on the request
parameters you specify:

* With only `s3vectors:QueryVectors` permission, you can retrieve
  vector keys of approximate nearest neighbors and computed
  distances between these vectors. This permission is sufficient
  only when you don't set any metadata filters and don't request
  vector data or metadata (by keeping the `returnMetadata` parameter
  set to `false` or not specified).

* If you specify a metadata filter or set `returnMetadata` to true,
  you must have both `s3vectors:QueryVectors` and
  `s3vectors:GetVectors` permissions. The request fails with a `403
  Forbidden error` if you request metadata filtering, vector data,
  or metadata without the `s3vectors:GetVectors` permission.

Examples:

Request syntax with placeholder values


resp = client.query_vectors({
  vector_bucket_name: "VectorBucketName",
  index_name: "IndexName",
  index_arn: "IndexArn",
  top_k: 1, # required
  query_vector: { # required
    float32: [1.0],
  },
  filter: {
  },
  return_metadata: false,
  return_distance: false,
})

Response structure


resp.vectors #=> Array
resp.vectors[0].distance #=> Float
resp.vectors[0].key #=> String
resp.distance_metric #=> String, one of "euclidean", "cosine"

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :vector_bucket_name (String)

    The name of the vector bucket that contains the vector index.

  • :index_name (String)

    The name of the vector index that you want to query.

  • :index_arn (String)

    The ARN of the vector index that you want to query.

  • :top_k (required, Integer)

    The number of results to return for each query.

  • :query_vector (required, Types::VectorData)

    The query vector. Ensure that the query vector has the same dimension as the dimension of the vector index that’s being queried. For example, if your vector index contains vectors with 384 dimensions, your query vector must also have 384 dimensions.

  • :filter (Hash, Array, String, Numeric, Boolean)

    Metadata filter to apply during the query. For more information about metadata keys, see [Metadata filtering] in the *Amazon S3 User Guide*.

    Document type used to carry open content (Hash,Array,String,Numeric,Boolean). A document type value is serialized using the same format as its surroundings and requires no additional encoding or escaping.

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-vectors-metadata-filtering.html

  • :return_metadata (Boolean)

    Indicates whether to include metadata in the response. The default value is ‘false`.

  • :return_distance (Boolean)

    Indicates whether to include the computed distance in the response. The default value is ‘false`.

Returns:

See Also:



1479
1480
1481
1482
# File 'lib/aws-sdk-s3vectors/client.rb', line 1479

def query_vectors(params = {}, options = {})
  req = build_request(:query_vectors, params)
  req.send_request(options)
end

#tag_resource(params = {}) ⇒ Struct

Applies one or more user-defined tags to an Amazon S3 Vectors resource or updates existing tags. Each tag is a label consisting of a key and value pair. Tags can help you organize, track costs for, and control access to your resources. You can add up to 50 tags for each resource.

<note markdown=“1”> For a list of S3 resources that support tagging, see [Managing tags for Amazon S3 resources].

</note>

Permissions

: For vector buckets and vector indexes, you must have the

`s3vectors:TagResource` permission to use this operation.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/tagging.html#manage-tags

Examples:

Request syntax with placeholder values


resp = client.tag_resource({
  resource_arn: "ResourceARN", # required
  tags: { # required
    "TagKey" => "TagValue",
  },
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    The Amazon Resource Name (ARN) of the Amazon S3 Vectors resource that you’re applying tags to. The tagged resource can be a vector bucket or a vector index.

  • :tags (required, Hash<String,String>)

    The user-defined tag that you want to add to the specified S3 Vectors resource. For more information, see [Tagging for cost allocation or attribute-based access control (ABAC)].

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/tagging.html

Returns:

  • (Struct)

    Returns an empty response.

See Also:



1532
1533
1534
1535
# File 'lib/aws-sdk-s3vectors/client.rb', line 1532

def tag_resource(params = {}, options = {})
  req = build_request(:tag_resource, params)
  req.send_request(options)
end

#untag_resource(params = {}) ⇒ Struct

Removes the specified user-defined tags from an Amazon S3 Vectors resource. You can pass one or more tag keys.

<note markdown=“1”> For a list of S3 resources that support tagging, see [Managing tags for Amazon S3 resources].

</note>

Permissions

: For vector buckets and vector indexes, you must have the

`s3vectors:UntagResource` permission to use this operation.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/tagging.html#manage-tags

Examples:

Request syntax with placeholder values


resp = client.untag_resource({
  resource_arn: "ResourceARN", # required
  tag_keys: ["TagKey"], # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    The Amazon Resource Name (ARN) of the Amazon S3 Vectors resource that you’re removing tags from. The tagged resource can be a vector bucket or a vector index.

  • :tag_keys (required, Array<String>)

    The array of tag keys that you’re removing from the S3 Vectors resource. For more information, see [Tagging for cost allocation or attribute-based access control (ABAC)].

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/tagging.html

Returns:

  • (Struct)

    Returns an empty response.

See Also:



1581
1582
1583
1584
# File 'lib/aws-sdk-s3vectors/client.rb', line 1581

def untag_resource(params = {}, options = {})
  req = build_request(:untag_resource, params)
  req.send_request(options)
end

#waiter_namesObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


1610
1611
1612
# File 'lib/aws-sdk-s3vectors/client.rb', line 1610

def waiter_names
  []
end